middleware

package
v1.1.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 2, 2026 License: MIT Imports: 15 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func ActivityMonitor

func ActivityMonitor(c http.Context)

ActivityMonitor capture and log all request/response.

func MetadataHeader

func MetadataHeader(c http.Context)

MetadataHeader set metadata information come from request header to current context.

func Recover

func Recover(c http.Context)

Recover do recover when panic occurring anywhere in the stack. Also give back standardized response by utilizing stderr & stdresp pkg.

Types

This section is empty.

Jump to